#!/usr/bin/env python

import logging

logger = logging.getLogger("winkar_log_util")

logger.setLevel(logging.WARN)

formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')

streamHandler = logging.StreamHandler()
streamHandler.setFormatter(formatter)

logger.addHandler(ch)



#!/usr/bin/env python

from multiprocessing.dummy import Pool as thread_pool

def multiThread(threads=10):
    def __multiThread(func):
        def threadedFunc(iterable):
            pool = thread_pool(threads)
            for x in pool.map(func, iterable): yield x
        return threadedFunc
    return __multiThread



#!/usr/bin/env python

import unittest
from utils.concurrent import multiThread
import time

class concurrentTest(unittest.TestCase):
    def test_multiThread(self):
        @multiThread(10)
        def ox(x):
            return x

        linput=range(10)
        for k,res in enumerate(ox(linput)):
            self.assertEqual(linput[k],res)

if __name__=="__main__":
    unittest.main()



PACKAGE = "utils"
NAME = "winkar_utils"
DESCRIPTION = "Util functions for python"
AUTHOR = "WinKaR"
AUTHOR_EMAIL = "winkar@163.com"
VERSION = __import__(PACKAGE).__version__

try:
    from pypandoc import convert
    read_md = lambda f: convert(f, 'rst',format="md")
except ImportError:
    print("warning: pypandoc module not found, could not convert Markdown to RST")
    read_md = lambda f: open(f, 'r').read()

from setuptools import *

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=read_md("README.md"),
    install_requires=[],
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license="BSD",
    packages=find_packages(exclude=["tests.*", "test"]),
    zip_safe=False,
    data_files=["README.md"],
)
